package App::cdif::Tmpfile;

use v5.14;
use warnings;
use utf8;

use parent 'Command::Run::Tmpfile';

1;

__END__

=encoding utf-8

=head1 NAME

App::cdif::Tmpfile - Compatibility wrapper for Command::Run::Tmpfile

=head1 DESCRIPTION

This module is an alias for L<Command::Run::Tmpfile> for backward
compatibility.  New code should use L<Command::Run::Tmpfile> directly.

=head1 SEE ALSO

L<Command::Run::Tmpfile>

=cut
